<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="551"/>
        <source>URI and driver do not match.</source>
        <translation>O URI e o controlador não coincidem.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="553"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>Instale o hplip primeiro e reinicie a aplicação para instalar o controlador novamente.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="561"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>Selecione um controlador hplip e tente novamente.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="574"/>
        <source>URI can&apos;t be empty</source>
        <translation>O URI não pode estar vazio</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="581"/>
        <source> not found</source>
        <translation>não encontrado</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>Verifique as definições da impressora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>A verificar as definições da impressora...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>Falha ao obter os atributos da impressora, erro: </translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>%1 está desativada</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>não está a aceitar trabalhos</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>As definições da impressora estão corretas</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>Verifique a ligação da impressora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>A verificar a ligação da impressora...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>Não é possível ligar à impressora, erro: %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation> não está ligado, URI:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 não existe</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>Não é possível ligar à impressora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>A ligação é válida</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>Verificar o servidor CUPS</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>A verificar o servidor CUPS...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>O servidor CUPS é inválido</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>O servidor CUPS é válido</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>A verificar controlador...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>Ficheiro PPD %1 não encontrado</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>O controlador está danificado</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>Filtro do controlador %1 não encontrado</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 não está instalado, não pode imprimir agora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>O controlador é válido</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>Verificar controlador</translation>
    </message>
</context>
<context>
    <name>DPrinterSupplyShowDlg</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="166"/>
        <source>Low level</source>
        <translation>Nível baixo</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="196"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="261"/>
        <source>Ink/Toner Status</source>
        <translation>Estado da tinta/toner</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="268"/>
        <source>Unknown amount</source>
        <translation>Montante desconhecido</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="276"/>
        <source>Unable to get the remaining amount</source>
        <translation>Incapaz de obter o montante restante</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="312"/>
        <source>The amounts are estimated, last updated at %1</source>
        <translation>Os montantes são estimados, atualizados pela última vez em %1</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="325"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceitar</translation>
    </message>
</context>
<context>
    <name>DPrinterTanslator</name>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="33"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="34"/>
        <location filename="../util/dprintertanslator.cpp" line="35"/>
        <source>Grayscale</source>
        <translation>Escala de cinza</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="38"/>
        <location filename="../util/dprintertanslator.cpp" line="69"/>
        <location filename="../util/dprintertanslator.cpp" line="86"/>
        <location filename="../util/dprintertanslator.cpp" line="107"/>
        <location filename="../util/dprintertanslator.cpp" line="126"/>
        <location filename="../util/dprintertanslator.cpp" line="135"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="39"/>
        <location filename="../util/dprintertanslator.cpp" line="49"/>
        <source>Draft</source>
        <translation>Rascunho</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="40"/>
        <location filename="../util/dprintertanslator.cpp" line="120"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="43"/>
        <location filename="../util/dprintertanslator.cpp" line="44"/>
        <location filename="../util/dprintertanslator.cpp" line="47"/>
        <source>Print Quality</source>
        <translation>Qualidade de impressão</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="48"/>
        <location filename="../util/dprintertanslator.cpp" line="60"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="52"/>
        <location filename="../util/dprintertanslator.cpp" line="53"/>
        <location filename="../util/dprintertanslator.cpp" line="54"/>
        <source>Paper Source</source>
        <translation>Fonte do papel</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="55"/>
        <location filename="../util/dprintertanslator.cpp" line="56"/>
        <source>Auto-Select</source>
        <translation>Seleção automática</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="57"/>
        <location filename="../util/dprintertanslator.cpp" line="58"/>
        <source>Manual Feeder</source>
        <translation>Alimentador manual</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="59"/>
        <location filename="../util/dprintertanslator.cpp" line="73"/>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="61"/>
        <source>Drawer 1</source>
        <translation>Bandeja 1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="62"/>
        <source>Drawer 2</source>
        <translation>Bandeja 2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="63"/>
        <source>Drawer 3</source>
        <translation>Bandeja 3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="64"/>
        <source>Drawer 4</source>
        <translation>Bandeja 4</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="65"/>
        <source>Drawer 5</source>
        <translation>Bandeja 5</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="66"/>
        <source>Envelope Feeder</source>
        <translation>Alimentador de envelopes</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="67"/>
        <source>Tray1</source>
        <translation>Bandeja1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="68"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="72"/>
        <source>MediaType</source>
        <translation>Tipo de suporte</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="74"/>
        <source>Plain Paper</source>
        <translation>Papel normal</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="75"/>
        <source>Recycled Paper</source>
        <translation>Papel reciclado</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="76"/>
        <source>Color Paper</source>
        <translation>Papel colorido</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="77"/>
        <source>Bond Paper</source>
        <translation>Papel autocolante</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="78"/>
        <source>Heavy Paper 1</source>
        <translation>Papel espesso 1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="79"/>
        <source>Heavy Paper 2</source>
        <translation>Papel espesso 2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="80"/>
        <source>Heavy Paper 3</source>
        <translation>Papel espesso 3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="81"/>
        <location filename="../util/dprintertanslator.cpp" line="82"/>
        <source>OHP</source>
        <translation>OHP</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="83"/>
        <source>Labels</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="84"/>
        <source>Envelope</source>
        <translation>Envelope</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="85"/>
        <source>Photo Paper</source>
        <translation>Papel fotográfico</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="89"/>
        <location filename="../util/dprintertanslator.cpp" line="90"/>
        <location filename="../util/dprintertanslator.cpp" line="91"/>
        <source>PageSize</source>
        <translation>Tamanho da página</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="92"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="95"/>
        <location filename="../util/dprintertanslator.cpp" line="96"/>
        <location filename="../util/dprintertanslator.cpp" line="97"/>
        <source>Duplex</source>
        <translation>Frente e verso</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="98"/>
        <source>DuplexTumble</source>
        <translation>Frente e verso a virar</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="99"/>
        <source>DuplexNoTumble</source>
        <translation>Frente e verso sem virar</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="100"/>
        <source>ON (Long-edged Binding)</source>
        <translation>LIGADO (encadernação de margem longa)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="101"/>
        <source>ON (Short-edged Binding)</source>
        <translation>LIGADO (encadernação de margem curta)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="102"/>
        <location filename="../util/dprintertanslator.cpp" line="103"/>
        <source>OFF</source>
        <translation>DESLIGADO</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="106"/>
        <location filename="../util/dprintertanslator.cpp" line="110"/>
        <source>Binding Edge</source>
        <translation>Margem de encadernação</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="108"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="109"/>
        <source>Top</source>
        <translation>Topo</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="113"/>
        <source>Portrait (no rotation)</source>
        <translation>Retrato (sem rotação)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="114"/>
        <source>Landscape (90 degrees)</source>
        <translation>Paisagem (90 graus)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="115"/>
        <source>Reverse landscape (270 degrees)</source>
        <translation>Paisagem inversa (270 graus)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="116"/>
        <source>Reverse portrait (180 degrees)</source>
        <translation>Retrato inverso (180 graus)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="117"/>
        <source>Auto Rotation</source>
        <translation>Rotação automática</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="121"/>
        <source>Reverse</source>
        <translation>Inverso</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="124"/>
        <location filename="../util/dprintertanslator.cpp" line="125"/>
        <source>Staple Location</source>
        <translation>Localização do agrafo</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="127"/>
        <source>Bind</source>
        <translation>Ligação</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="128"/>
        <source>Bind (none)</source>
        <translation>Ligação (nenhuma)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="129"/>
        <source>Bind (bottom)</source>
        <translation>Ligação (inferior)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="130"/>
        <source>Bind (left)</source>
        <translation>Ligação (esquerda)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="131"/>
        <source>Bind (right)</source>
        <translation>Ligação (direita)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="132"/>
        <source>Bind (top)</source>
        <translation>Ligação (superior)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="136"/>
        <location filename="../util/dprintertanslator.cpp" line="137"/>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
</context>
<context>
    <name>DPrintersShowWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="91"/>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="99"/>
        <source>Printers</source>
        <translation>Impressoras</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="104"/>
        <source>Add printer</source>
        <translation>Adicionar impressora</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="107"/>
        <source>Delete printer</source>
        <translation>Eliminar impressora</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="142"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="143"/>
        <source>Shared</source>
        <translation>Partilhada</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="146"/>
        <source>Enabled</source>
        <translation>Ativada</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="149"/>
        <source>Accept jobs</source>
        <translation>Aceitar trabalhos</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="153"/>
        <source>Set as default</source>
        <translation>Definir como predefinida</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="166"/>
        <source>No Printers</source>
        <translation>Sem impressoras</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="193"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="198"/>
        <source>Model:</source>
        <translation>Modelo:</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="201"/>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="237"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="665"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="667"/>
        <source>Print Queue</source>
        <translation>Fila de impressão</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="670"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="672"/>
        <source>Print Test Page</source>
        <translation>Imprimir página de teste</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="274"/>
        <source>Supplies</source>
        <translation>Suprimentos</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="310"/>
        <source>No printer configured</source>
        <translation>Nenhuma impressora configurada</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="316"/>
        <source>Click + to add printers</source>
        <translation>Clicar em + para adicionar impressoras</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="365"/>
        <source>As print jobs are in process, you cannot rename the printer now, please try later</source>
        <translation>Como os trabalhos de impressão estão em processo, não pode renomear a impressora agora, tente mais tarde</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="369"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="428"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="786"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="425"/>
        <source>CUPS server is not running, and can’t manage printers.</source>
        <translation>O servidor CUPS não está em execução e não pode gerir impressoras.</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="692"/>
        <source>Idle</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="694"/>
        <source>Printing</source>
        <translation>A imprimir</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="696"/>
        <source>Disabled</source>
        <translation>Desativada</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="744"/>
        <source>Are you sure you want to delete the printer &quot;%1&quot; ?</source>
        <translation>Tem a certeza que pretende eliminar a impressora &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="750"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="782"/>
        <source>The name already exists</source>
        <translation>O nome já existe</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="801"/>
        <source>You will not be able to reprint the completed jobs if continue. Are you sure you want to rename the printer?</source>
        <translation>Não poderá reimprimir os trabalhos concluídos se continuar. Tem a certeza de que deseja renomear a impressora?</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="806"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="865"/>
        <source>The driver is damaged, please install it again.</source>
        <translation>O controlador está danificado, instale-o novamente.</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="868"/>
        <source>Install Driver</source>
        <translation>Instalar controlador</translation>
    </message>
</context>
<context>
    <name>DPropertySetDlg</name>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="261"/>
        <source>Print Properties</source>
        <translation>Propriedades de impressão</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="262"/>
        <source>Driver</source>
        <translation>Controlador</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="263"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="264"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="265"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="266"/>
        <source>Color Mode</source>
        <translation>Modo de cor</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="267"/>
        <source>Orientation</source>
        <translation>Orientação</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="268"/>
        <source>Page Order</source>
        <translation>Ordem de página</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="703"/>
        <source>Options conflict!</source>
        <translation>Opções em conflito!</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="706"/>
        <source>Please resolve the conflict first, and then save the changes.</source>
        <translation>Primeiro resolva o conflito e de seguida, guarde as alterações.</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="725"/>
        <source>Conflict:</source>
        <translation>Conflito:</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="736"/>
        <location filename="../ui/dpropertysetdlg.cpp" line="1234"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="1233"/>
        <source>Invalid URI</source>
        <translation>URI inválido</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1031"/>
        <source>EveryWhere driver</source>
        <translation>Controlador universal</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="373"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>Falha ao encontrar a solução do controlador: %1, erro: %2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="384"/>
        <source>The solution is invalid</source>
        <translation>A solução é inválida</translation>
    </message>
</context>
<context>
    <name>InstallDriverWindow</name>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="103"/>
        <location filename="../ui/installdriverwindow.cpp" line="107"/>
        <source>Select a driver from</source>
        <translation>Selecione um controlador de</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="113"/>
        <location filename="../ui/installdriverwindow.cpp" line="116"/>
        <source>Local driver</source>
        <translation>Controlador local</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="118"/>
        <location filename="../ui/installdriverwindow.cpp" line="121"/>
        <source>Local PPD file</source>
        <translation>Ficheiro PPD local</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="123"/>
        <location filename="../ui/installdriverwindow.cpp" line="126"/>
        <source>Search for a driver</source>
        <translation>Procurar por um controlador</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="146"/>
        <location filename="../ui/installdriverwindow.cpp" line="464"/>
        <source>Choose a local driver</source>
        <translation>Escolha um controlador local</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="150"/>
        <source>Vendor</source>
        <translation>Fornecedor</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="164"/>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="177"/>
        <location filename="../ui/installdriverwindow.cpp" line="259"/>
        <source>Driver</source>
        <translation>Controlador</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="242"/>
        <source>Vendor and Model</source>
        <translation>Fornecedor e modelo</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="244"/>
        <source>Enter a complete vendor and model (Only letters, numbers and whitespaces)</source>
        <translation>Introduza um fornecedor e modelo completo (Apenas letras, números e espaços em branco)</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="247"/>
        <source>Search</source>
        <comment>button</comment>
        <translation>Procurar</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="296"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>Instalar o controlador</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="446"/>
        <location filename="../ui/installdriverwindow.cpp" line="556"/>
        <source>Reselect</source>
        <translation>Selecionar novamente</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="472"/>
        <location filename="../ui/installdriverwindow.cpp" line="553"/>
        <source>Select a PPD file</source>
        <translation>Selecione um ficheiro PPD</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="481"/>
        <source>Search for printer driver</source>
        <translation>Procurar por controlador de impressora</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="535"/>
        <source>(recommended)</source>
        <translation>(recomendado)</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="707"/>
        <source> (recommended)</source>
        <translation>(recomendado)</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="251"/>
        <source>is invalid</source>
        <translation>é inválido</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="280"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>Falha ao instalar o controlador ao chamar a interface dbus</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="325"/>
        <source>Failed to install %1</source>
        <translation>Falha ao instalar o %1</translation>
    </message>
</context>
<context>
    <name>InstallPrinterWindow</name>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="87"/>
        <location filename="../ui/installprinterwindow.cpp" line="163"/>
        <source>Installing driver...</source>
        <translation>A instalar o controlador...</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="97"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="100"/>
        <location filename="../ui/installprinterwindow.cpp" line="186"/>
        <location filename="../ui/installprinterwindow.cpp" line="203"/>
        <source>View Printer</source>
        <comment>button</comment>
        <translation>Ver impressora</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="102"/>
        <location filename="../ui/installprinterwindow.cpp" line="188"/>
        <location filename="../ui/installprinterwindow.cpp" line="205"/>
        <source>Print Test Page</source>
        <comment>button</comment>
        <translation>Imprimir página de teste</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="175"/>
        <source>Successfully installed </source>
        <translation>Instalação bem sucedida</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="181"/>
        <location filename="../ui/installprinterwindow.cpp" line="199"/>
        <source>You have successfully added the printer. Print a test page to check if it works properly.</source>
        <translation>Adicionou a impressora com sucesso. Imprima uma página de teste para verificar se funciona corretamente.</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="193"/>
        <source>Printing test page...</source>
        <translation>A imprimir página de teste...</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="210"/>
        <source>Did you print the test page successfully?</source>
        <translation>Imprimiu a página de teste com sucesso?</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="216"/>
        <source>If succeeded, click Yes; if failed, click No</source>
        <translation>se for bem sucedido, clique em Sim; se falhar, clique em Não</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="219"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="221"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="226"/>
        <location filename="../ui/installprinterwindow.cpp" line="246"/>
        <source>Print failed</source>
        <translation>A impressão falhou</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="232"/>
        <source>Click Reinstall to install the printer driver again, or click Troubleshoot to start troubleshooting.</source>
        <translation>Clique em Reinstalar para instalar novamente o controlador da impressora ou clique em Resolução de problemas para iniciar a resolução de problemas.</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="235"/>
        <location filename="../ui/installprinterwindow.cpp" line="256"/>
        <source>Reinstall</source>
        <comment>button</comment>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="237"/>
        <location filename="../ui/installprinterwindow.cpp" line="258"/>
        <source>Troubleshoot</source>
        <comment>button</comment>
        <translation>Resolução de problemas</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="244"/>
        <source>Installation failed</source>
        <translation>A instalação falhou</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="252"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="253"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="254"/>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="255"/>
        <source>Resume</source>
        <translation>Retomar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="256"/>
        <source>Print first</source>
        <translation>Imprimir primeiro</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="257"/>
        <source>Reprint</source>
        <translation>Reimprimir</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="259"/>
        <source>No print jobs</source>
        <translation>Sem trabalhos de impressão</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="405"/>
        <source>Are you sure you want to delete this job?</source>
        <translation>Tem a certeza que deseja eliminar este trabalho?</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="411"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="412"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>não encontrado</translation>
    </message>
</context>
<context>
    <name>JobManagerWindow</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1099"/>
        <source>Refresh</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1105"/>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1106"/>
        <source>Print Queue</source>
        <translation>Fila de impressão</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1107"/>
        <source>Completed</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1176"/>
        <source> failed</source>
        <translation>falhou</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1197"/>
        <source>%1 jobs</source>
        <translation>%1 trabalhos</translation>
    </message>
</context>
<context>
    <name>JobsDataModel</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="713"/>
        <source>Job</source>
        <translation>Trabalho</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="715"/>
        <source>User</source>
        <translation>Utilizador</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="717"/>
        <source>Document</source>
        <translation>Documento</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="719"/>
        <source>Printer</source>
        <translation>Impressora</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="721"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="723"/>
        <source>Time submitted</source>
        <translation>Hora do envio</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="725"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="727"/>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
</context>
<context>
    <name>PermissionsWindow</name>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="48"/>
        <source>Connect to %1 to find a printer</source>
        <translation>Ligar-se a %1 para encontrar uma impressora</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="74"/>
        <source>Username</source>
        <translation>Nome do utilizador</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="76"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="78"/>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="92"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="93"/>
        <source>Connect</source>
        <translation>Ligar</translation>
    </message>
</context>
<context>
    <name>PrinterApplication</name>
    <message>
        <location filename="../ui/printerapplication.cpp" line="104"/>
        <source>Print Manager</source>
        <translation>Gestor de Impressão</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="105"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>O Gestor de Impressão é uma ferramenta de gestão de impressoras, que suporta a adição e remoção de impressoras, gestão de trabalhos de impressão, etc.</translation>
    </message>
</context>
<context>
    <name>PrinterSearchWindow</name>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="88"/>
        <location filename="../ui/printersearchwindow.cpp" line="91"/>
        <source>Discover printer</source>
        <translation>Descubra a impressora</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="94"/>
        <location filename="../ui/printersearchwindow.cpp" line="97"/>
        <source>Find printer</source>
        <translation>Encontrar impressora</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="99"/>
        <location filename="../ui/printersearchwindow.cpp" line="102"/>
        <source>Enter URI</source>
        <translation>Introduzir URI</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="125"/>
        <source>Select a printer</source>
        <translation>Selecione uma impressora</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="132"/>
        <source>Refresh</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="155"/>
        <location filename="../ui/printersearchwindow.cpp" line="268"/>
        <source>No printers found</source>
        <translation>Nenhuma impressora encontrada</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="202"/>
        <source>Install Driver</source>
        <translation>Instalar controlador</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="233"/>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="236"/>
        <source>Enter an address</source>
        <translation>Introduzir um endereço</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="238"/>
        <source>Find</source>
        <comment>button</comment>
        <translation>Encontrar</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="346"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="351"/>
        <source>Enter device URI</source>
        <translation>Introduzir URI do dispositivo</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="376"/>
        <source>Examples:</source>
        <translation>Exemplos:</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="698"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="784"/>
        <source> (recommended)</source>
        <translation>(recomendado)</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="794"/>
        <source>The driver was found</source>
        <translation>O controlador foi encontrado</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="795"/>
        <source>Connect to the network and try again</source>
        <translation>Ligue-se à rede e tente novamente</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="797"/>
        <source>Cannot find the driver</source>
        <translation>Não foi possível encontrar o controlador</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="798"/>
        <source>Please try to install it manually or search its official website</source>
        <translation>Tente instalar manualmente ou pesquise no website oficial</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="808"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceitar</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>Verificar impressão da página de teste</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>A imprimir página de teste...</translation>
    </message>
</context>
<context>
    <name>PrinterTestPageDialog</name>
    <message>
        <location filename="../ui/printertestpagedialog.cpp" line="61"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="226"/>
        <source>Black</source>
        <translation>Preto</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="227"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="228"/>
        <source>Brown</source>
        <translation>Castanho</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="229"/>
        <source>Cyan</source>
        <translation>Ciano</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="230"/>
        <source>Dark-gray</source>
        <translation>Cinzento-escuro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="231"/>
        <source>Dark gray</source>
        <translation>Cinzento escuro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="232"/>
        <source>Dark-yellow</source>
        <translation>Amarelo-escuro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="233"/>
        <source>Dark yellow</source>
        <translation>Amarelo escuro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="234"/>
        <source>Gold</source>
        <translation>Dourado</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="235"/>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="236"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="237"/>
        <source>Light-black</source>
        <translation>Preto-claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="238"/>
        <source>Light black</source>
        <translation>Preto claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="239"/>
        <source>Light-cyan</source>
        <translation>Ciano-claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="240"/>
        <source>Light cyan</source>
        <translation>Ciano claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="241"/>
        <source>Light-gray</source>
        <translation>Cinzento-claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="242"/>
        <source>Light gray</source>
        <translation>Cinzento claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="243"/>
        <source>Light-magenta</source>
        <translation>Magenta-claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="244"/>
        <source>Light magenta</source>
        <translation>Magenta claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="245"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="246"/>
        <source>Orange</source>
        <translation>Laranja</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="247"/>
        <source>Red</source>
        <translation>Vermelho</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="248"/>
        <source>Silver</source>
        <translation>Prateado</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="249"/>
        <source>White</source>
        <translation>Branco</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="250"/>
        <source>Yellow</source>
        <translation>Amarelo</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="251"/>
        <source>Waste</source>
        <translation>Resíduos</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="108"/>
        <source>1 min ago</source>
        <translation>1 min atrás</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="111"/>
        <source>%1 mins ago</source>
        <translation>%1 mins atrás</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="115"/>
        <source>1 hr ago</source>
        <translation>1 hr atrás</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="117"/>
        <source>%1 hrs ago</source>
        <translation>%1 hrs atrás</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="122"/>
        <source>Yesterday</source>
        <translation>Ontem</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="124"/>
        <source>%1 days ago</source>
        <translation>%1 dias atrás</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="113"/>
        <source>Direct-attached Device</source>
        <translation>Dispositivo ligado diretamente</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="114"/>
        <source>File</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="616"/>
        <source>(use %1 protocol)</source>
        <translation>(utilizar protocolo %1)</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="26"/>
        <source>Select a driver</source>
        <translation>Selecione um controlador</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="32"/>
        <source>Driver</source>
        <translation>Controlador</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="33"/>
        <source>Next</source>
        <comment>button</comment>
        <translation>Seguinte</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="34"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>Instalar controlador</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="36"/>
        <source>Drag a PPD file here 
 or</source>
        <translation>Arraste um ficheiro PPD aqui 
 ou</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="37"/>
        <source>Select a PPD file</source>
        <comment>button</comment>
        <translation>Selecione um ficheiro PPD</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="39"/>
        <source>Troubleshoot</source>
        <translation>Resolução de problemas</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="40"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="43"/>
        <source>For more drivers, please refer to our official website: </source>
        <translation>Para mais controladores, visite o nosso website oficial:</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="201"/>
        <source>Idle</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="204"/>
        <source>Printing</source>
        <translation>A imprimir</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="207"/>
        <source>Disabled</source>
        <translation>Desativada</translation>
    </message>
    <message>
        <location filename="../util/dprinter.cpp" line="285"/>
        <source>(recommended)</source>
        <translation>(recomendado)</translation>
    </message>
    <message>
        <location filename="../ui/dprinterpropertytemplate.h" line="33"/>
        <source>Preferences</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenamePrinterWindow</name>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="84"/>
        <source>Rename Printer</source>
        <translation>Renomear a impressora</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="91"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="93"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="95"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="106"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="107"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>ServerSettingsWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="92"/>
        <source>Basic Server Settings</source>
        <translation>Definições básicas do servidor</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="101"/>
        <source>Publish shared printers connected to this system</source>
        <translation>Publicar impressoras partilhadas ligadas a este sistema</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="103"/>
        <source>Allow printing from the Internet</source>
        <translation>Permitir a impressão a partir da Internet</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="105"/>
        <source>Allow remote administration</source>
        <translation>Permitir administração remota</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="107"/>
        <source>Save debugging information for troubleshooting</source>
        <translation>Guardar informações de depuração para solução de problemas</translation>
    </message>
</context>
<context>
    <name>TroubleShootDialog</name>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="118"/>
        <source>Troubleshoot: </source>
        <translation>Resolução de problemas:</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="145"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="178"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceitar</translation>
    </message>
</context>
</TS>